'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var path = require('path');
var lodash = require('lodash');
var service = require('@tarojs/service');

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () {
                        return e[k];
                    }
                });
            }
        });
    }
    n['default'] = e;
    return Object.freeze(n);
}

var path__namespace = /*#__PURE__*/_interopNamespace(path);

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

const PACKAGE_NAME = 'plugin-platform-ysf';
class Ysf extends service.TaroPlatformBase {
    constructor() {
        super(...arguments);
        this.fileType = {
            templ: '.html',
            style: '.css',
            config: '.json',
            script: '.js',
        };
        this.runtimePath = `${PACKAGE_NAME}/dist/runtime`;
    }
}

var index = (ctx) => {
    ctx.registerPlatform({
        name: 'ysf',
        useConfigName: 'h5',
        fn({ config }) {
            return __awaiter(this, void 0, void 0, function* () {
                const { appPath, outputPath, sourcePath } = ctx.paths;
                const { initialConfig } = ctx;
                const { port } = ctx.runOpts;
                const { emptyDirectory, recursiveMerge, npm, ENTRY, SOURCE_DIR, OUTPUT_DIR, } = ctx.helper;
                emptyDirectory(outputPath);
                const entryFileName = `${ENTRY}.config`;
                const entryFile = path__namespace.basename(entryFileName);
                const defaultEntry = {
                    [ENTRY]: [path__namespace.join(sourcePath, entryFile)],
                };
                const customEntry = lodash.get(initialConfig, 'h5.entry');
                const h5RunnerOpts = recursiveMerge(Object.assign({}, config), {
                    entryFileName: ENTRY,
                    env: {
                        TARO_ENV: JSON.stringify('h5'),
                        FRAMEWORK: JSON.stringify(config.framework),
                        TARO_VERSION: require(path__namespace.join(ctx.paths.nodeModulesPath, '@tarojs/taro/package.json')).version,
                    },
                    port,
                    sourceRoot: config.sourceRoot || SOURCE_DIR,
                    outputRoot: config.outputRoot || OUTPUT_DIR,
                });
                h5RunnerOpts.entry = lodash.merge(defaultEntry, customEntry);
                const webpackRunner = yield npm.getNpmPkg('@tarojs/webpack-runner', appPath);
                webpackRunner(appPath, h5RunnerOpts);
            });
        },
    });
};

exports.Ysf = Ysf;
exports['default'] = index;
//# sourceMappingURL=index.js.map
